# Stubs for docutils.parsers.rst.directives (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.parsers.rst import Directive
from types import ModuleType
from typing import Callable, List, Optional, Pattern, Sequence, Tuple, Type

__docformat__: str

def directive(directive_name: str, language_module: ModuleType, document: nodes.document) -> Tuple[Optional[Type[Directive]], List[nodes.system_message]]: ...
def register_directive(name: str, directive: Type[Directive]) -> None: ...
def flag(argument: str) -> None: ...
def unchanged_required(argument: str) -> str: ...
def unchanged(argument: str) -> str: ...
def path(argument: str) -> str: ...
def uri(argument: str) -> str: ...
def nonnegative_int(argument: str) -> int: ...
def percentage(argument: str) -> int: ...

length_units: List[str]

def get_measure(argument: str, units: List[str]) -> float: ...
def length_or_unitless(argument: str) -> float: ...
def length_or_percentage_or_unitless(argument: str, default: str = ...) -> float: ...
def class_option(argument: str) -> List[str]: ...

unicode_pattern: Pattern

def unicode_code(code: str) -> str: ...
def single_char_or_unicode(argument: str) -> str: ...
def single_char_or_whitespace_or_unicode(argument: str) -> str: ...
def positive_int(argument: str) -> int: ...
def positive_int_list(argument: str) -> List[int]: ...
def encoding(argument: str) -> str: ...
def choice(argument: str, values: Sequence[str]) -> str: ...
def format_values(values: Sequence[str]) -> str: ...
def value_or(values: List[str], other: Callable[[str], str]) -> Callable[[str], str]: ...



# Stubs for docutils.transforms.components (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.transforms import Transform

__docformat__: str

class Filter(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore



# Stubs for docutils.io (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import TransformSpec
from typing import Any, IO, List, Optional, Pattern, Tuple

__docformat__: str

class InputError(IOError): ...
class OutputError(IOError): ...

def check_encoding(stream: IO, encoding: str) -> Optional[bool]: ...

class Input(TransformSpec):
    component_type: str = ...
    default_source_path: str = ...
    encoding: str = ...
    error_handler: str = ...
    source: IO = ...
    source_path: str = ...
    successful_encoding: str = ...
    def __init__(self, source: Optional[Any] = ..., source_path: Optional[str] = ..., encoding: Optional[str] = ..., error_handler: str = ...) -> None: ...
    def read(self) -> str: ...
    def decode(self, data: str) -> str: ...
    coding_slug: Pattern[bytes] = ...
    byte_order_marks: Tuple[Tuple[bytes, str], ...] = ...
    def determine_encoding_from_data(self, data: str) -> str: ...

class Output(TransformSpec):
    component_type: str = ...
    default_destination_path: str = ...
    encoding: str = ...
    error_handler: str = ...
    destination: Any = ...
    destination_path: str = ...
    def __init__(self, destination: Optional[Any] = ..., destination_path: Optional[str] = ..., encoding: Optional[str] = ..., error_handler: str = ...) -> None: ...
    def write(self, data: str): ...
    def encode(self, data: str) -> str: ...

class FileInput(Input):
    autoclose: bool = ...
    source: IO = ...
    source_path: str = ...
    def __init__(self, source: Optional[IO] = ..., source_path: Optional[str] = ..., encoding: Optional[str] = ..., error_handler: str = ..., autoclose: bool = ..., mode: str = ..., **kwargs) -> None: ...
    def read(self) -> str: ...
    def readlines(self) -> List[str]: ...
    def close(self) -> None: ...

class FileOutput(Output):
    mode: str = ...
    opened: bool = ...
    autoclose: bool = ...
    destination: IO = ...
    destination_path: str = ...
    def __init__(self, destination: Optional[IO] = ..., destination_path: Optional[str] = ..., encoding: Optional[str] = ..., error_handler: str = ..., autoclose: bool = ..., handle_io_errors: Optional[Any] = ..., mode: Optional[str] = ...) -> None: ...
    def open(self) -> None: ...
    def write(self, data: str) -> str: ...
    def close(self) -> None: ...

class BinaryFileOutput(FileOutput):
    mode: str = ...

class StringInput(Input):
    default_source_path: str = ...
    def read(self) -> str: ...

class StringOutput(Output):
    default_destination_path: str = ...
    destination: str = ...
    def write(self, data: str) -> str: ...

class NullInput(Input):
    default_source_path: str = ...
    def read(self) -> str: ...

class NullOutput(Output):
    default_destination_path: str = ...
    def write(self, data: str) -> None: ...

class DocTreeInput(Input):
    default_source_path: str = ...
    def read(self) -> str: ...



# Stubs for docutils.parsers.rst.directives.tables (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

import csv
from docutils.statemachine import StringList
from docutils.nodes import Node, system_message, table, title
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Tuple, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

def align(argument: str) -> str: ...

class Table(Directive):
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def make_title(self) -> Tuple[title, List[system_message]]: ...
    def process_header_option(self) -> Tuple[List[Node], int]: ...
    def check_table_dimensions(self, rows: List[List[N_co]], header_rows: int, stub_columns: int) -> None: ...
    @property
    def widths(self) -> str: ...
    def get_column_widths(self, max_cols: int) -> List[int]: ...
    def extend_short_rows_with_empty_cells(self, columns: int, parts: Tuple[List[N_co], List[N_co]]) -> None: ...

class RSTTable(Table):
    def run(self) -> List[N_co]: ...

class CSVTable(Table):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    class DocutilsDialect(csv.Dialect):
        delimiter: str = ...
        quotechar: str = ...
        doublequote: bool = ...
        skipinitialspace: bool = ...
        strict: bool = ...
        lineterminator: str = ...
        quoting: Any = ...
        escapechar: str = ...
        def __init__(self, options: Dict[str, Any]) -> None: ...
    class HeaderDialect(csv.Dialect):
        delimiter: str = ...
        quotechar: str = ...
        escapechar: str = ...
        doublequote: bool = ...
        skipinitialspace: bool = ...
        strict: bool = ...
        lineterminator: str = ...
        quoting: Any = ...
    def check_requirements(self) -> None: ...
    def run(self) -> List[N_co]: ...
    def get_csv_data(self) -> Tuple[List[str], str]: ...
    decode_from_csv: Callable[[str], str] = ...
    encode_for_csv: Callable[[str], str] = ...
    def parse_csv_data_into_rows(self, csv_data: List[str], dialect: Any, source: str) -> Tuple[List[Tuple[int, int, int, StringList]], int]: ...

class ListTable(Table):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...
    def check_list_content(self, node: Node) -> Tuple[int, List[int]]: ...
    def build_table_from_list(self, table_data: List[List[N_co]], col_widths: List[int], header_rows: int, stub_columns: int) -> table: ...



# Stubs for docutils.writers.odf_odt.pygmentsformatter (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

import pygments.formatter
from pygments.token import _TokenType
from typing import Any, Sequence, Tuple, TextIO

class OdtPygmentsFormatter(pygments.formatter.Formatter):
    rststyle_function: Any = ...
    escape_function: Any = ...
    def __init__(self, rststyle_function: Any, escape_function: Any) -> None: ...
    def rststyle(self, name: Any, parameters: Any = ...) -> Any: ...

class OdtPygmentsProgFormatter(OdtPygmentsFormatter):
    def format(self, tokensource: Sequence[Tuple[_TokenType, str]], outfile: TextIO) -> None: ...

class OdtPygmentsLaTeXFormatter(OdtPygmentsFormatter):
    def format(self, tokensource: Sequence[Tuple[_TokenType, str]], outfile: TextIO) -> None: ...



# Stubs for docutils.writers (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import Component
from docutils.io import Output
from docutils.transforms import Transform
from types import ModuleType
from typing import Any, Dict, List, Type, Union

__docformat__: str

class Writer(Component):
    component_type: str = ...
    config_section: str = ...
    def get_transforms(self) -> List[Type[Transform]]: ...
    document: Any = ...
    output: Union[bytes, str] = ...
    language: ModuleType = ...
    destination: Output = ...
    parts: Dict[Any, Any] = ...
    def __init__(self) -> None: ...
    def write(self, document: Any, destination: Output) -> Any: ...
    def translate(self) -> None: ...
    def assemble_parts(self) -> None: ...

class UnfilteredWriter(Writer):
    def get_transforms(self) -> List[Type[Transform]]: ...

def get_writer_class(writer_name) -> Type[Writer]: ...



# Stubs for docutils.examples (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.core import Publisher
from typing import Any, Dict, Optional, Tuple

def html_parts(input_string, source_path: Optional[Any] = ..., destination_path: Optional[Any] = ..., input_encoding: str = ..., doctitle: bool = ..., initial_header_level: int = ...) -> Dict[str, Any]: ...
def html_body(input_string, source_path: Optional[Any] = ..., destination_path: Optional[Any] = ..., input_encoding: str = ..., output_encoding: str = ..., doctitle: bool = ..., initial_header_level: int = ...) -> Any: ...
def internals(input_string, source_path: Optional[Any] = ..., destination_path: Optional[Any] = ..., input_encoding: str = ..., settings_overrides: Optional[Any] = ...) -> Tuple[Any, Publisher]: ...



# Stubs for docutils.languages.it (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Dict, List

__docformat__: str
labels: Dict[str, str]
bibliographic_fields: Dict[str, str]
author_separators: List[str]



# Stubs for docutils.utils (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import ApplicationError, DataError
from docutils import nodes
from docutils.frontend import Values
from docutils.io import Output
from typing import Any, Dict, Callable, Generator, IO, List, Mapping, Optional, Pattern, Tuple, Union

__docformat__: str

class SystemMessage(ApplicationError):
    level: int = ...
    def __init__(self, system_message: nodes.system_message, level: int) -> None: ...

class SystemMessagePropagation(ApplicationError): ...

class Reporter:
    levels: List[str] = ...
    DEBUG_LEVEL: int = ...
    INFO_LEVEL: int = ...
    WARNING_LEVEL: int = ...
    ERROR_LEVEL: int = ...
    SEVERE_LEVEL: int = ...
    source: str = ...
    error_handler: str = ...
    debug_flag: bool = ...
    report_level: int = ...
    halt_level: int = ...
    stream: Optional[Union[IO, str, bool]] = ...
    encoding: str = ...
    observers: List[Callable[[nodes.system_message], None]] = ...
    max_level: int = ...
    def __init__(self, source: str, report_level: int, halt_level: int, stream: Optional[Union[IO, str, bool]] = ..., debug: bool = ..., encoding: Optional[Any] = ..., error_handler: str = ...) -> None: ...
    def set_conditions(self, category: Any, report_level: int, halt_level: int, stream: Optional[IO] = ..., debug: bool = ...) -> None: ...
    def attach_observer(self, observer: Callable[[nodes.system_message], None]) -> None: ...
    def detach_observer(self, observer: Callable[[nodes.system_message], None]) -> None: ...
    def notify_observers(self, message: nodes.system_message) -> None: ...
    def system_message(self, level: int, message: str, *children: nodes.Node, **kwargs: Any) -> nodes.system_message: ...
    def debug(self, *args: Any, **kwargs: Any) -> nodes.system_message: ...
    def info(self, *args: Any, **kwargs: Any) -> nodes.system_message: ...
    def warning(self, *args: Any, **kwargs: Any) -> nodes.system_message: ...
    def error(self, *args: Any, **kwargs: Any) -> nodes.system_message: ...
    def severe(self, *args: Any, **kwargs: Any) -> nodes.system_message: ...

class ExtensionOptionError(DataError): ...
class BadOptionError(ExtensionOptionError): ...
class BadOptionDataError(ExtensionOptionError): ...
class DuplicateOptionError(ExtensionOptionError): ...

def extract_extension_options(field_list: nodes.field_list, options_spec: Dict[str, Callable[[str], Any]]) -> Dict[str, Any]: ...
def extract_options(field_list: nodes.field_list) -> List[Tuple[str, str]]: ...
def assemble_option_dict(option_list: List[Tuple[str, str]], options_spec: Mapping[str, Callable[[str], Any]]) -> Dict[str, Any]: ...

class NameValueError(DataError): ...

def decode_path(path: str) -> str: ...
def extract_name_value(line: str) -> List[Tuple[str, str]]: ...
def new_reporter(source_path: str, settings: Values) -> Reporter: ...
def new_document(source_path: str, settings: Optional[Values] = ...) -> nodes.document: ...
def clean_rcs_keywords(paragraph: nodes.paragraph, keyword_substitutions: List[Tuple[Pattern, str]]) -> None: ...
def relative_path(source: str, target: str) -> str: ...
def get_stylesheet_reference(settings: Values, relative_to: Optional[str] = ...) -> str: ...
def get_stylesheet_list(settings: Values) -> List[str]: ...
def find_file_in_dirs(path: str, dirs: List[str]) -> str: ...
def get_trim_footnote_ref_space(settings: Values) -> bool: ...
def get_source_line(node: nodes.Node) -> Tuple[str, int]: ...
def escape2null(text: str) -> str: ...
def unescape(text: str, restore_backslashes: bool = ..., respect_whitespace: bool = ...) -> str: ...
def split_escaped_whitespace(text: str) -> List[str]: ...
def strip_combining_chars(text: str) -> str: ...
def find_combining_chars(text: str) -> List[int]: ...
def column_indices(text: str) -> List[int]: ...

east_asian_widths: Dict[str, int]

def column_width(text: str) -> int: ...
def uniq(L: List) -> List: ...
def unique_combinations(items: List, n: int) -> Generator[List, None, None]: ...
def normalize_language_tag(tag): ...

class DependencyList:
    def __init__(self, output_file: Optional[str] = ..., dependencies: List[str] = ...) -> None: ...
    list: List[str] = ...
    file: Output = ...
    def set_output(self, output_file: str) -> None: ...
    def add(self, *filenames: str) -> None: ...
    def close(self) -> None: ...

release_level_abbreviations: Dict[str, str]

def version_identifier(version_info: Optional[Tuple[int, int, int, str, int, bool]] = ...) -> str: ...



# Stubs for docutils.readers.standalone (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils import readers
from docutils.transforms import Transform
from typing import Any, Dict, List, Sequence, Tuple, Type

__docformat__: str

class Reader(readers.Reader):
    supported: Tuple[str, ...] = ...
    document: nodes.document = ...
    settings_spec: Tuple[str, str, Tuple[str, List[str], Dict[str, Any]]] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    def get_transforms(self) -> List[Type[Transform]]: ...



# Stubs for docutils.writers.latex2e (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes, writers
from docutils.transforms import Transform
from docutils.writers import latex2e
from types import ModuleType
from typing import Any, Dict, List, Optional, Pattern, Sequence, Tuple, Type, Union

__docformat__: str

class Writer(writers.Writer):
    supported: Tuple[str, ...] = ...
    default_template: str = ...
    default_template_path: str = ...
    default_preamble: str = ...
    table_style_values: Tuple[str, ...] = ...
    settings_spec: Tuple[str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...]] = ...
    settings_defaults: Dict[str, int] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    head_parts: Tuple[str, ...] = ...
    visitor_attributes: Tuple[str, ...] = ...
    output: Any = ...
    translator_class: Type[latex2e.LaTeXTranslator] = ...
    def __init__(self) -> None: ...
    def get_transforms(self) -> List[Type[Transform]]: ...
    def translate(self) -> None: ...
    def assemble_parts(self) -> None: ...

class Babel:
    language_codes: Dict[str, str] = ...
    warn_msg: str = ...
    active_chars: Dict[str, str] = ...
    reporter: Any = ...
    language: str = ...
    otherlanguages: Dict[Any, Any] = ...
    def __init__(self, language_code: str, reporter: Optional[Any] = ...) -> None: ...
    setup: List[str] = ...
    def __call__(self) -> str: ...
    def language_name(self, language_code: str) -> str: ...
    def get_language(self) -> str: ...

class SortableDict(dict):
    def sortedkeys(self) -> List[Any]: ...
    def sortedvalues(self) -> List[Any]: ...

class PreambleCmds: ...

class CharMaps:
    alltt: Dict[int, str] = ...
    special: Dict[int, str] = ...
    unsupported_unicode: Dict[int, str] = ...
    utf8_supported_unicode: Dict[int, str] = ...
    textcomp: Dict[int, str] = ...
    pifont: Dict[int, str] = ...

class DocumentClass:
    document_class: str = ...
    sections: List[str] = ...
    def __init__(self, document_class: str, with_part: bool = ...) -> None: ...
    def section(self, level: int) -> str: ...

class Table:
    stubs: List[Any] = ...
    colwidths_auto: bool = ...
    def __init__(self, translator: latex2e.LaTeXTranslator, latex_type: str) -> None: ...
    caption: List[str] = ...
    def open(self) -> None: ...
    def close(self) -> None: ...
    def is_open(self) -> bool: ...
    borders: List[str] = ...
    def set_table_style(self, table_style: Sequence[str], classes: Sequence[str]): ...
    def get_latex_type(self) -> str: ...
    def set(self, attr: Any, value: Any) -> None: ...
    def get(self, attr: Any) -> Any: ...
    def get_vertical_bar(self) -> str: ...
    def get_opening(self) -> str: ...
    def get_closing(self) -> str: ...
    def visit_colspec(self, node: nodes.colspec) -> None: ...
    def get_colspecs(self, node: nodes.Node) -> str: ...
    def get_column_width(self) -> str: ...
    def get_multicolumn_width(self, start: int, len_: int) -> str: ...
    def get_caption(self) -> str: ...
    def need_recurse(self) -> Union[bool, int]: ...
    def visit_thead(self) -> List[str]: ...
    def depart_thead(self) -> List[str]: ...
    def visit_row(self) -> None: ...
    def depart_row(self) -> List[str]: ...
    def set_rowspan(self, cell: Any, value: Any) -> None: ...
    def get_rowspan(self, cell: Any) -> Any: ...
    def get_entry_number(self) -> Optional[int]: ...
    def visit_entry(self) -> None: ...
    def is_stub_column(self) -> Any: ...

class LaTeXTranslator(nodes.NodeVisitor):
    is_xetex: bool = ...
    compound_enumerators: bool = ...
    section_prefix_for_enumerators: bool = ...
    section_enumerator_separator: str = ...
    has_latex_toc: bool = ...
    is_toc_list: bool = ...
    section_level: int = ...
    inside_citation_reference_label: bool = ...
    verbatim: bool = ...
    insert_non_breaking_blanks: bool = ...
    insert_newline: bool = ...
    literal: bool = ...
    alltt: bool = ...
    warn: Any = ...
    error: Any = ...
    settings: Any = ...
    latex_encoding: str = ...
    use_latex_toc: bool = ...
    use_latex_docinfo: bool = ...
    hyperlink_color: str = ...
    font_encoding: str = ...
    literal_block_env: str = ...
    literal_block_options: str = ...
    bibtex: Optional[str] = ...
    language_module: ModuleType = ...
    babel: Any = ...
    author_separator: List[str] = ...
    documentoptions: str = ...
    d_class: DocumentClass = ...
    graphicx_package: str = ...
    docutils_footnotes: bool = ...
    head_prefix: List[str] = ...
    requirements: SortableDict = ...
    latex_preamble: List[Any] = ...
    fallbacks: SortableDict = ...
    pdfsetup: List[str] = ...
    title: List[str] = ...
    subtitle: List[str] = ...
    titledata: List[str] = ...
    body_pre_docinfo: List[str] = ...
    docinfo: List[str] = ...
    dedication: List[Any] = ...
    abstract: List[Any] = ...
    body: List[str] = ...
    context: List[Any] = ...
    title_labels: List[str] = ...
    subtitle_labels: List[str] = ...
    author_stack: List[List[str]] = ...
    date: List[str] = ...
    pdfinfo: List[str] = ...
    pdfauthor: List[str] = ...
    table_stack: List[Any] = ...
    active_table: Table = ...
    out: List[str] = ...
    out_stack: List[Any] = ...
    stylesheet: List[str] = ...
    hyperref_options: str = ...
    def __init__(self, document: nodes.document, babel_class: Any = ...) -> None: ...
    def stylesheet_call(self, path: str) -> str: ...
    def to_latex_encoding(self, docutils_encoding: str) -> str: ...
    def language_label(self, docutil_label: str) -> str: ...
    def encode(self, text: str) -> str: ...
    def attval(self, text: str, whitespace: Pattern[str] = ...) -> str: ...
    def is_inline(self, node: nodes.Node) -> bool: ...
    def append_hypertargets(self, node: nodes.Node) -> None: ...
    def ids_to_labels(self, node: nodes.Node, set_anchor: bool = ...) -> List[str]: ...
    def set_align_from_classes(self, node: nodes.Node) -> None: ...
    def insert_align_declaration(self, node: nodes.Node, default: Optional[Any] = ...) -> None: ...
    def duclass_open(self, node: nodes.Node) -> None: ...
    def duclass_close(self, node: nodes.Node) -> None: ...
    def push_output_collector(self, new_out: Any) -> None: ...
    def pop_output_collector(self) -> None: ...
    def visit_Text(self, node: nodes.Text) -> None: ...
    def depart_Text(self, node: nodes.Text) -> None: ...
    def visit_abbreviation(self, node: nodes.abbreviation) -> None: ...
    def depart_abbreviation(self, node: nodes.abbreviation) -> None: ...
    def visit_acronym(self, node: nodes.acronym) -> None: ...
    def depart_acronym(self, node: nodes.acronym) -> None: ...
    def visit_address(self, node: nodes.address) -> None: ...
    def depart_address(self, node: nodes.address) -> None: ...
    def visit_admonition(self, node: nodes.admonition) -> None: ...
    def depart_admonition(self, node: Optional[nodes.admonition] = ...) -> None: ...
    def visit_author(self, node: nodes.author) -> None: ...
    def depart_author(self, node: nodes.author) -> None: ...
    def visit_authors(self, node: nodes.authors) -> None: ...
    def depart_authors(self, node: nodes.authors) -> None: ...
    def visit_block_quote(self, node: nodes.block_quote) -> None: ...
    def depart_block_quote(self, node: nodes.block_quote) -> None: ...
    def visit_bullet_list(self, node: nodes.bullet_list) -> None: ...
    def depart_bullet_list(self, node: nodes.bullet_list) -> None: ...
    def visit_superscript(self, node: nodes.superscript) -> None: ...
    def depart_superscript(self, node: nodes.superscript) -> None: ...
    def visit_subscript(self, node: nodes.subscript) -> None: ...
    def depart_subscript(self, node: nodes.subscript) -> None: ...
    def visit_caption(self, node: nodes.caption) -> None: ...
    def depart_caption(self, node: nodes.caption) -> None: ...
    def visit_title_reference(self, node: nodes.title_reference) -> None: ...
    def depart_title_reference(self, node: nodes.title_reference) -> None: ...
    def visit_citation(self, node: nodes.citation) -> None: ...
    def depart_citation(self, node: nodes.citation) -> None: ...
    def visit_citation_reference(self, node: nodes.citation_reference) -> None: ...
    def depart_citation_reference(self, node: nodes.citation_reference) -> None: ...
    def visit_classifier(self, node: nodes.classifier) -> None: ...
    def depart_classifier(self, node: nodes.classifier) -> None: ...
    def visit_colspec(self, node: nodes.colspec) -> None: ...
    def depart_colspec(self, node: nodes.colspec) -> None: ...
    def visit_comment(self, node: nodes.comment) -> None: ...
    def depart_comment(self, node: nodes.comment) -> None: ...
    def visit_compound(self, node: nodes.compound) -> None: ...
    def depart_compound(self, node: nodes.compound) -> None: ...
    def visit_contact(self, node: nodes.contact) -> None: ...
    def depart_contact(self, node: nodes.contact) -> None: ...
    def visit_container(self, node: nodes.container) -> None: ...
    def depart_container(self, node: nodes.container) -> None: ...
    def visit_copyright(self, node: nodes.copyright) -> None: ...
    def depart_copyright(self, node: nodes.copyright) -> None: ...
    def visit_date(self, node: nodes.date) -> None: ...
    def depart_date(self, node: nodes.date) -> None: ...
    def visit_decoration(self, node: nodes.decoration) -> None: ...
    def depart_decoration(self, node: nodes.decoration) -> None: ...
    def visit_definition(self, node: nodes.definition) -> None: ...
    def depart_definition(self, node: nodes.definition) -> None: ...
    def visit_definition_list(self, node: nodes.definition_list) -> None: ...
    def depart_definition_list(self, node: nodes.definition_list) -> None: ...
    def visit_definition_list_item(self, node: nodes.definition_list_item) -> None: ...
    def depart_definition_list_item(self, node: nodes.definition_list_item) -> None: ...
    def visit_description(self, node: nodes.description) -> None: ...
    def depart_description(self, node: nodes.description) -> None: ...
    def visit_docinfo(self, node: nodes.docinfo) -> None: ...
    def depart_docinfo(self, node: nodes.docinfo) -> None: ...
    def visit_docinfo_item(self, node: nodes.Element, name: str) -> None: ...
    def depart_docinfo_item(self, node: nodes.Element) -> None: ...
    def visit_doctest_block(self, node: nodes.doctest_block) -> None: ...
    def depart_doctest_block(self, node: nodes.doctest_block) -> None: ...
    def visit_document(self, node: nodes.document) -> None: ...
    def depart_document(self, node: nodes.document) -> None: ...
    def visit_emphasis(self, node: nodes.emphasis) -> None: ...
    def depart_emphasis(self, node: nodes.emphasis) -> None: ...
    def insert_additional_table_colum_delimiters(self) -> None: ...
    def visit_entry(self, node: nodes.entry) -> None: ...
    def depart_entry(self, node: nodes.entry) -> None: ...
    def visit_row(self, node: nodes.row) -> None: ...
    def depart_row(self, node: nodes.row) -> None: ...
    def visit_enumerated_list(self, node: nodes.enumerated_list) -> None: ...
    def depart_enumerated_list(self, node: nodes.enumerated_list) -> None: ...
    def visit_field(self, node: nodes.field) -> None: ...
    def depart_field(self, node: nodes.field) -> None: ...
    def visit_field_argument(self, node: nodes.Node) -> None: ...
    def depart_field_argument(self, node: nodes.Node) -> None: ...
    def visit_field_body(self, node: nodes.field_body) -> None: ...
    def depart_field_body(self, node: nodes.field_body) -> None: ...
    def visit_field_list(self, node: nodes.field_list) -> None: ...
    def depart_field_list(self, node: nodes.field_list) -> None: ...
    def visit_field_name(self, node: nodes.field_name) -> None: ...
    def depart_field_name(self, node: nodes.field_name) -> None: ...
    def visit_figure(self, node: nodes.figure) -> None: ...
    def depart_figure(self, node: nodes.figure) -> None: ...
    def visit_footer(self, node: nodes.footer) -> None: ...
    def depart_footer(self, node: nodes.footer) -> None: ...
    def visit_footnote(self, node: nodes.footnote) -> None: ...
    def depart_footnote(self, node: nodes.footnote) -> None: ...
    def visit_footnote_reference(self, node: nodes.footnote_reference) -> None: ...
    def depart_footnote_reference(self, node: nodes.footnote_reference) -> None: ...
    def label_delim(self, node: nodes.Node, bracket: str, superscript: str) -> None: ...
    def visit_label(self, node: nodes.label) -> None: ...
    def depart_label(self, node: nodes.label) -> None: ...
    def visit_generated(self, node: nodes.generated) -> None: ...
    def depart_generated(self, node: nodes.generated) -> None: ...
    def visit_header(self, node: nodes.header) -> None: ...
    def depart_header(self, node: nodes.header) -> None: ...
    def to_latex_length(self, length_str: str, pxunit: Optional[Any] = ...) -> str: ...
    def visit_image(self, node: nodes.image) -> None: ...
    def depart_image(self, node: nodes.image) -> None: ...
    def visit_inline(self, node: nodes.inline) -> None: ...
    def depart_inline(self, node: nodes.inline) -> None: ...
    def visit_interpreted(self, node: nodes.Node) -> None: ...
    def depart_interpreted(self, node: nodes.Node) -> None: ...
    def visit_legend(self, node: nodes.legend) -> None: ...
    def depart_legend(self, node: nodes.legend) -> None: ...
    def visit_line(self, node: nodes.line) -> None: ...
    def depart_line(self, node: nodes.line) -> None: ...
    def visit_line_block(self, node: nodes.line_block) -> None: ...
    def depart_line_block(self, node: nodes.line_block) -> None: ...
    def visit_list_item(self, node: nodes.list_item) -> None: ...
    def depart_list_item(self, node: nodes.list_item) -> None: ...
    def visit_literal(self, node: nodes.literal) -> None: ...
    def depart_literal(self, node: nodes.literal) -> None: ...
    def is_plaintext(self, node: nodes.Node) -> bool: ...
    def visit_literal_block(self, node: nodes.literal_block) -> None: ...
    def depart_literal_block(self, node: nodes.literal_block) -> None: ...
    def visit_math(self, node: nodes.math, math_env: str = ...) -> None: ...
    def depart_math(self, node: nodes.math) -> None: ...
    def visit_math_block(self, node: nodes.math_block) -> None: ...
    def depart_math_block(self, node: nodes.math_block) -> None: ...
    def visit_option(self, node: nodes.option) -> None: ...
    def depart_option(self, node: nodes.option) -> None: ...
    def visit_option_argument(self, node: nodes.option_argument) -> None: ...
    def depart_option_argument(self, node: nodes.option_argument) -> None: ...
    def visit_option_group(self, node: nodes.option_group) -> None: ...
    def depart_option_group(self, node: nodes.option_group) -> None: ...
    def visit_option_list(self, node: nodes.option_list) -> None: ...
    def depart_option_list(self, node: nodes.option_list) -> None: ...
    def visit_option_list_item(self, node: nodes.option_list_item) -> None: ...
    def depart_option_list_item(self, node: nodes.option_list_item) -> None: ...
    def visit_option_string(self, node: nodes.option_string) -> None: ...
    def depart_option_string(self, node: nodes.option_string) -> None: ...
    def visit_organization(self, node: nodes.organization) -> None: ...
    def depart_organization(self, node: nodes.organization) -> None: ...
    def visit_paragraph(self, node: nodes.paragraph) -> None: ...
    def depart_paragraph(self, node: nodes.paragraph) -> None: ...
    def visit_problematic(self, node: nodes.problematic) -> None: ...
    def depart_problematic(self, node: nodes.problematic) -> None: ...
    def visit_raw(self, node: nodes.raw) -> None: ...
    def depart_raw(self, node: nodes.raw) -> None: ...
    def has_unbalanced_braces(self, string: str) -> bool: ...
    def visit_reference(self, node: nodes.reference) -> None: ...
    def depart_reference(self, node: nodes.reference) -> None: ...
    def visit_revision(self, node: nodes.revision) -> None: ...
    def depart_revision(self, node: nodes.revision) -> None: ...
    def visit_rubric(self, node: nodes.rubric) -> None: ...
    def depart_rubric(self, node: nodes.rubric) -> None: ...
    def visit_section(self, node: nodes.section) -> None: ...
    def depart_section(self, node: nodes.section) -> None: ...
    def visit_sidebar(self, node: nodes.sidebar) -> None: ...
    def depart_sidebar(self, node: nodes.sidebar) -> None: ...
    attribution_formats: Dict[str, Tuple[str, str]] = ...
    def visit_attribution(self, node: nodes.attribution) -> None: ...
    def depart_attribution(self, node: nodes.attribution) -> None: ...
    def visit_status(self, node: nodes.status) -> None: ...
    def depart_status(self, node: nodes.status) -> None: ...
    def visit_strong(self, node: nodes.strong) -> None: ...
    def depart_strong(self, node: nodes.strong) -> None: ...
    def visit_substitution_definition(self, node: nodes.substitution_definition) -> None: ...
    def visit_substitution_reference(self, node: nodes.substitution_reference) -> None: ...
    def visit_subtitle(self, node: nodes.subtitle) -> None: ...
    def depart_subtitle(self, node: nodes.subtitle) -> None: ...
    def visit_system_message(self, node: nodes.system_message) -> None: ...
    def depart_system_message(self, node: nodes.system_message) -> None: ...
    def visit_table(self, node: nodes.table) -> None: ...
    def depart_table(self, node: nodes.table) -> None: ...
    def visit_target(self, node: nodes.target) -> None: ...
    def depart_target(self, node: nodes.target) -> None: ...
    def visit_tbody(self, node: nodes.tbody) -> None: ...
    def depart_tbody(self, node: nodes.tbody) -> None: ...
    def visit_term(self, node: nodes.term) -> None: ...
    def depart_term(self, node: nodes.term) -> None: ...
    def visit_tgroup(self, node: nodes.tgroup) -> None: ...
    def depart_tgroup(self, node: nodes.tgroup) -> None: ...
    def thead_depth(self) -> int: ...
    def visit_thead(self, node: nodes.thead) -> None: ...
    def depart_thead(self, node: nodes.thead) -> None: ...
    def visit_title(self, node: nodes.title) -> None: ...
    def depart_title(self, node: nodes.title) -> None: ...
    def minitoc(self, node: nodes.Node, title: str, depth: int) -> None: ...
    def visit_topic(self, node: nodes.topic) -> None: ...
    def depart_topic(self, node: nodes.topic) -> None: ...
    def visit_transition(self, node: nodes.transition) -> None: ...
    def depart_transition(self, node: nodes.transition) -> None: ...
    def visit_version(self, node: nodes.version) -> None: ...
    def depart_version(self, node: nodes.version) -> None: ...
    def unimplemented_visit(self, node: nodes.Node) -> None: ...



# Stubs for docutils.transforms.universal (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.transforms import Transform
from typing import Dict, Generator, List, Optional, Set, Text, Tuple, Type

__docformat__: str

class Decorations(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore
    def generate_header(self) -> Optional[nodes.Node]: ...
    def generate_footer(self) -> Optional[List[nodes.paragraph]]: ...

class ExposeInternals(Transform):
    default_priority: int = ...
    def not_Text(self, node: nodes.Node) -> bool: ...
    def apply(self) -> None: ...  # type: ignore

class Messages(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class FilterMessages(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class TestMessages(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class StripComments(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class StripClassesAndElements(Transform):
    default_priority: int = ...
    strip_elements: Dict[Type, None] = ...
    strip_classes: Dict[Type, None] = ...
    def apply(self) -> None: ...  # type: ignore
    def check_classes(self, node: nodes.Node) -> Optional[int]: ...

class SmartQuotes(Transform):
    default_priority: int = ...
    nodes_to_skip: Tuple[nodes.Node, ...] = ...
    literal_nodes: Tuple[nodes.Node, ...] = ...
    smartquotes_action: str = ...
    unsupported_languages: Set[str] = ...
    def __init__(self, document: nodes.document, startnode: nodes.Node) -> None: ...
    def get_tokens(self, txtnodes: List[nodes.Text]) -> Generator[Tuple[str, Text], None, None]: ...
    def apply(self) -> None: ...  # type: ignore



# Stubs for docutils.writers.html5_polyglot (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.parsers.rst.directives.html import MetaBody
from docutils.writers import _html_base, html5_polyglot
from typing import Any, Dict, List, Tuple, Type

__docformat__: str

class Writer(_html_base.Writer):
    supported: Tuple[str, ...] = ...
    default_stylesheets: List[str] = ...
    default_stylesheet_dirs: List[str] = ...
    default_template: str = ...
    default_template_path: str = ...
    settings_spec: Tuple[str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...]] = ...
    config_section: str = ...
    parts: Dict[Any, Any] = ...
    translator_class: Type[html5_polyglot.HTMLTranslator] = ...
    def __init__(self) -> None: ...

class HTMLTranslator(_html_base.HTMLTranslator):
    def visit_acronym(self, node: nodes.acronym) -> None: ...
    def depart_acronym(self, node: nodes.acronym) -> None: ...
    def visit_authors(self, node: nodes.authors) -> None: ...
    def depart_authors(self, node: nodes.authors) -> None: ...
    def visit_copyright(self, node: nodes.copyright) -> None: ...
    def depart_copyright(self, node: nodes.copyright) -> None: ...
    def visit_date(self, node: nodes.date) -> None: ...
    def depart_date(self, node: nodes.date) -> None: ...
    def visit_meta(self, node: MetaBody.meta) -> None: ...
    def depart_meta(self, node: MetaBody.meta) -> None: ...
    def visit_organization(self, node: nodes.organization) -> None: ...
    def depart_organization(self, node: nodes.organization) -> None: ...



# Stubs for docutils.utils.punctuation_chars (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Dict

openers: str
closers: str
delimiters: str
closing_delimiters: str
quote_pairs: Dict[str, str]

def match_chars(c1: str, c2: str) -> bool: ...



# Stubs for docutils.readers.doctree (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils import readers
from typing import Sequence, Tuple

class Reader(readers.ReReader):
    supported: Tuple[str, ...] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    document: nodes.document = ...
    def parse(self) -> None: ...



# Stubs for docutils._compat (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, List, Mapping

b = str
bytes = str
u_prefix: str

def __import__(name, globals: Mapping[Any, Any] = ..., locals: Mapping[Any, Any] = ..., fromlist: List[Any] = ..., level: int = ...): ...



# Stubs for docutils.parsers.rst.languages (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from types import ModuleType

__docformat__: str

def get_language(language_code: str) -> ModuleType: ...



# Stubs for docutils.writers.s5_html (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.writers import html4css1, s5_html
from typing import Any, Dict, List, Optional, Pattern, Tuple, Type

__docformat__: str
themes_dir_path: str

def find_theme(name: str): ...

class Writer(html4css1.Writer):
    settings_spec: Tuple[str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...], str, Any, Tuple[Tuple[str, List[str], Dict[str, Any]], ...]] = ...  # type: ignore
    settings_default_overrides: Dict[str, int] = ...
    config_section: str = ...
    config_section_dependencies: Tuple[str, ...] = ...
    translator_class: Type[s5_html.S5HTMLTranslator] = ...
    def __init__(self) -> None: ...

class S5HTMLTranslator(html4css1.HTMLTranslator):
    s5_stylesheet_template: str = ...
    disable_current_slide: str = ...
    layout_template: str = ...
    default_theme: str = ...
    base_theme_file: str = ...
    direct_theme_files: Tuple[str] = ...
    indirect_theme_files: Tuple[str] = ...
    required_theme_files: Tuple[str] = ...
    theme_file_path: str = ...
    s5_footer: List[str] = ...
    s5_header: List[str] = ...
    section_count: int = ...
    theme_files_copied: Optional[Dict[str, int]] = ...
    def __init__(self, *args) -> None: ...
    def setup_theme(self) -> None: ...
    def copy_theme(self) -> None: ...
    files_to_skip_pattern: Pattern[str] = ...
    def copy_file(self, name: str, source_dir: str, dest_dir: str) -> Optional[int]: ...
    def depart_document(self, node: nodes.document) -> None: ...
    def depart_footer(self, node: nodes.footer) -> None: ...
    def depart_header(self, node: nodes.header) -> None: ...
    def visit_section(self, node: nodes.section) -> None: ...
    def visit_subtitle(self, node: nodes.subtitle) -> None: ...
    def visit_title(self, node: nodes.title) -> None: ...



# Stubs for docutils.utils.code_analyzer (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import ApplicationError
from typing import Any, Generator, List, Tuple

with_pygments: bool
unstyled_tokens: List[str]

class LexerError(ApplicationError): ...

class Lexer:
    code: str = ...
    language: str = ...
    tokennames: str = ...
    lexer: Any = ...
    def __init__(self, code: str, language: str, tokennames: str = ...) -> None: ...
    def merge(self, tokens: List[Tuple[str, str]]) -> Generator[Tuple[str, str], None, None]: ...
    def __iter__(self) -> Generator[Tuple[List[str], str], None, None]: ...

class NumberLines:
    tokens: Tuple[List[str], str] = ...
    startline: int = ...
    fmt_str: int = ...
    def __init__(self, tokens: Tuple[List[str], str], startline: int, endline: int) -> None: ...
    def __iter__(self) -> Generator[Tuple[str, str], None, None]: ...



# Stubs for docutils.transforms.frontmatter (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Bibliographic, docinfo, field_list, Node, topic, Text
from docutils.transforms import Transform
from typing import Dict, List, Optional, Pattern, Tuple, Type, TypeVar, Union

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class TitlePromoter(Transform):
    def promote_title(self, node: Node) -> Optional[int]: ...
    def promote_subtitle(self, node: Node) -> Optional[int]: ...
    def candidate_index(self, node: Node) -> Tuple[Optional[Node], Optional[int]]: ...

class DocTitle(TitlePromoter):
    default_priority: int = ...
    def set_metadata(self) -> None: ...
    def apply(self) -> None: ...  # type: ignore

class SectionSubTitle(TitlePromoter):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class DocInfo(Transform):
    default_priority: int = ...
    biblio_nodes: Dict[str, Union[Type[Bibliographic], Type[topic]]] = ...
    def apply(self) -> None: ...  # type: ignore
    def extract_bibliographic(self, field_list: field_list) -> List[Union[Bibliographic, topic]]: ...
    def check_empty_biblio_field(self, field: Node, name: str) -> Optional[int]: ...
    def check_compound_biblio_field(self, field: Node, name: str) -> Optional[int]: ...
    rcs_keyword_substitutions: List[Tuple[Pattern, str]] = ...
    def extract_authors(self, field: Node, name: str, docinfo: docinfo) -> None: ...
    def authors_from_one_paragraph(self, field: Node) -> List[List[Text]]: ...
    def authors_from_bullet_list(self, field: Node) -> List[List[N_co]]: ...
    def authors_from_paragraphs(self, field: Node) -> List[List[N_co]]: ...



# Stubs for docutils.parsers.rst.directives.parts (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Node
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Tuple, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class Contents(Directive):
    backlinks_values: Tuple[str, ...] = ...
    def backlinks(arg): ...
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class Sectnum(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class Header(Directive):
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class Footer(Directive):
    has_content: bool = ...
    def run(self) -> List[N_co]: ...



# Stubs for docutils.parsers.rst.directives.admonitions (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.nodes import Node, admonition, attention, caution, danger, error, hint, important, note, tip, warning
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Type, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class BaseAdmonition(Directive):
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    node_class: Type[nodes.Admonition] = ...
    def run(self) -> List[N_co]: ...

class Admonition(BaseAdmonition):
    required_arguments: int = ...
    node_class: Type[admonition] = ...

class Attention(BaseAdmonition):
    node_class: Type[attention] = ...

class Caution(BaseAdmonition):
    node_class: Type[caution] = ...

class Danger(BaseAdmonition):
    node_class: Type[danger] = ...

class Error(BaseAdmonition):
    node_class: Type[error] = ...

class Hint(BaseAdmonition):
    node_class: Type[hint] = ...

class Important(BaseAdmonition):
    node_class: Type[important] = ...

class Note(BaseAdmonition):
    node_class: Type[note] = ...

class Tip(BaseAdmonition):
    node_class: Type[tip] = ...

class Warning(BaseAdmonition):
    node_class: Type[warning] = ...



# Stubs for docutils.parsers.rst.states (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import ApplicationError, DataError
from docutils import nodes
from docutils.parsers.rst import Directive, states, tableparser
from docutils.statemachine import StateMachine, StateMachineWS, StateWS, StringList
from docutils.utils import Reporter
from types import ModuleType
from typing import Any, Callable, Dict, List, Match, MutableSequence, Optional, Pattern, Sequence, Tuple, Type, TypeVar, Union

BasicDefinition = Tuple[str, str, str, List[Pattern]]
DefinitionParts = Tuple[str, str, str, List[Union[Pattern, BasicDefinition]]]
DefinitionType = Tuple[str, str, str, List[Union[Pattern, DefinitionParts]]]
N_co = TypeVar('N_co', bound=nodes.Node, covariant=True)

__docformat__: str

class MarkupError(DataError): ...
class UnknownInterpretedRoleError(DataError): ...
class InterpretedRoleNotImplementedError(DataError): ...
class ParserError(ApplicationError): ...
class MarkupMismatch(Exception): ...

class Struct:
    def __init__(self, **keywordargs) -> None: ...

class RSTStateMachine(StateMachineWS):
    language: ModuleType = ...
    match_titles: bool = ...
    memo: Struct = ...
    document: nodes.document = ...
    reporter: Reporter = ...
    node: nodes.Node = ...
    def run(self, input_lines: Union[List[str], StringList], document: nodes.document, input_offset: int = ..., match_titles: bool = ..., inliner: Optional[states.Inliner] = ...) -> None: ...  # type: ignore

class NestedStateMachine(StateMachineWS):
    match_titles: bool = ...
    memo: Struct = ...
    document: nodes.document = ...
    reporter: Reporter = ...
    language: ModuleType = ...
    node: nodes.Node = ...
    def run(self, input_lines: Union[List[str], StringList], input_offset: int, memo: Struct, node: nodes.Node, match_titles: bool = ...) -> List[Any]: ...    # type: ignore

class RSTState(StateWS):
    nested_sm: Type[StateMachine] = ...
    nested_sm_cache: List[StateMachine] = ...
    nested_sm_kwargs: Dict[str, Any] = ...
    def __init__(self, state_machine: StateMachine, debug: bool = ...) -> None: ...
    memo: Struct = ...
    reporter: Reporter = ...
    inliner: states.Inliner = ...
    document: nodes.document = ...
    parent: nodes.Node = ...
    def runtime_init(self) -> None: ...
    def goto_line(self, abs_line_offset: int) -> None: ...
    def no_match(self, context, transitions: Tuple[List[str], Dict[str, Tuple[Pattern, Callable, str]]]) -> Tuple[Any, str, List]: ...
    def bof(self, context) -> Tuple[List, List]: ...
    def nested_parse(self, block: StringList, input_offset: int, node: nodes.Node, match_titles: bool = ..., state_machine_class: Optional[Type[StateMachine]] = ..., state_machine_kwargs: Optional[Dict[str, Any]] = ...) -> int: ...
    def nested_list_parse(self, block, input_offset, node, initial_state, blank_finish, blank_finish_state: Optional[Any] = ..., extra_settings: Any = ..., match_titles: bool = ..., state_machine_class: Optional[Any] = ..., state_machine_kwargs: Optional[Any] = ...): ...
    def section(self, title: str, source: str, style: str, lineno: int, messages: List[str]) -> None: ...
    def check_subsection(self, source: str, style: str, lineno: int) -> int: ...
    def title_inconsistent(self, sourcetext: str, lineno: int) -> nodes.system_message: ...
    def new_subsection(self, title: str, lineno: int, messages: List[nodes.system_message]) -> None: ...
    def paragraph(self, lines: List[str], lineno: int) -> Tuple[List[N_co], int]: ...
    def inline_text(self, text: str, lineno: int) -> Tuple[List[N_co], List[nodes.system_message]]: ...
    def unindent_warning(self, node_name: str) -> nodes.system_message: ...

def build_regexp(definition: DefinitionType, compile: bool = ...) -> Pattern: ...

class Inliner:
    implicit_dispatch: List[Tuple[Pattern, Callable]] = ...
    def __init__(self) -> None: ...
    start_string_prefix: str = ...
    end_string_suffix: str = ...
    parts: DefinitionType = ...
    patterns: Any = ...
    def init_customizations(self, settings: Any) -> None: ...
    reporter: Reporter = ...
    document: nodes.document = ...
    language: ModuleType = ...
    parent: nodes.Element = ...
    def parse(self, text: str, lineno: int, memo: Any, parent: nodes.Element) -> Tuple[List[N_co], List[nodes.system_message]]: ...
    non_whitespace_before: str = ...
    non_whitespace_escape_before: str = ...
    non_unescaped_whitespace_escape_before: str = ...
    non_whitespace_after: str = ...
    simplename: str = ...
    uric: str = ...
    uri_end_delim: str = ...
    urilast: str = ...
    uri_end: str = ...
    emailc: str = ...
    email_pattern: str = ...
    def quoted_start(self, match: Match) -> bool: ...
    def inline_obj(self, match: Match, lineno: int, end_pattern: Pattern, nodeclass: nodes.TextElement, restore_backslashes: bool = ...) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message], str]: ...
    def problematic(self, text: str, rawsource: str, message: nodes.system_message) -> nodes.problematic: ...
    def emphasis(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def strong(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def interpreted_or_phrase_ref(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def phrase_ref(self, before: str, after: str, rawsource: str, escaped: str, text: str) -> Tuple[str, List[N_co], str, List[N_co]]: ...
    def adjust_uri(self, uri: str) -> str: ...
    def interpreted(self, rawsource: str, text: str, role: str, lineno: int) -> Tuple[List[N_co], List[nodes.system_message]]: ...
    def literal(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def inline_internal_target(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def substitution_reference(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def footnote_reference(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def reference(self, match: Match, lineno: int, anonymous: bool = ...) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def anonymous_reference(self, match: Match, lineno: int) -> Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]: ...
    def standalone_uri(self, match: Match, lineno: int) -> List[Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]]: ...
    def pep_reference(self, match: Match, lineno: int) -> List[Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]]: ...
    rfc_url: str = ...
    def rfc_reference(self, match: Match, lineno: int) -> List[Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]]: ...
    def implicit_inline(self, text: str, lineno: int) -> List[nodes.Text]: ...
    dispatch: Dict[str, Callable[[Match, int], Tuple[str, List[nodes.problematic], str, List[nodes.system_message]]]] = ...

class Body(RSTState):
    double_width_pad_char: str = ...
    enum: Any = ...
    grid_table_top_pat: Pattern = ...
    simple_table_top_pat: Pattern = ...
    simple_table_border_pat: Pattern = ...
    pats: Dict[str, str] = ...
    patterns: Dict[str, Union[str, Pattern]] = ...
    initial_transitions: Union[Sequence[str], Sequence[Tuple[str, str]]] = ...
    def indent(self, match: Match, context: Any, next_state: str) -> Tuple[Any, str, List[Any]]: ...
    def block_quote(self, indented: StringList, line_offset: int) -> List[nodes.Element]: ...
    attribution_pattern: Pattern = ...
    def split_attribution(self, indented: StringList, line_offset: int) -> Tuple[StringList, Optional[StringList], Optional[int], Optional[StringList], Optional[int]]: ...
    def check_attribution(self, indented: StringList, attribution_start: int) -> Tuple[Optional[int], Optional[int]]: ...
    def parse_attribution(self, indented: StringList, line_offset: int) -> Tuple[nodes.attribution, List[nodes.system_message]]: ...
    def bullet(self, match: Match, context: Any, next_state: str) -> Optional[Tuple[List[Any], str, List[Any]]]: ...
    def list_item(self, indent: int) -> Tuple[nodes.list_item, bool]: ...
    def enumerator(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def parse_enumerator(self, match: Match, expected_sequence: Optional[Any] = ...) -> Tuple[str, str, str, Optional[str]]: ...
    def is_enumerated_list_item(self, ordinal: Optional[int], sequence: str, format: str) -> Optional[int]: ...
    def make_enumerator(self, ordinal: int, sequence: str, format: str) -> Optional[Tuple[str, str]]: ...
    def field_marker(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def field(self, match: Match) -> Tuple[nodes.field, bool]: ...
    def parse_field_marker(self, match: Match) -> str: ...
    def parse_field_body(self, indented: StringList, offset, node) -> None: ...
    def option_marker(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def option_list_item(self, match: Match) -> Tuple[nodes.option_list_item, bool]: ...
    def parse_option_marker(self, match: Match) -> List[Union[nodes.option, nodes.option_argument]]: ...
    def doctest(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def line_block(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def line_block_line(self, match: Match, lineno: int) -> Tuple[nodes.line, List[nodes.system_message], bool]: ...
    def nest_line_block_lines(self, block: nodes.line_block) -> None: ...
    def nest_line_block_segment(self, block: nodes.line_block) -> None: ...
    def grid_table_top(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def simple_table_top(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def table_top(self, match: Match, context: Any, next_state: str, isolate_function: Callable[[], Union[Tuple[List[Any], List[nodes.system_message], bool], Tuple[StringList, List[nodes.system_message], bool]]], parser_class: Union[Type[tableparser.GridTableParser], Type[tableparser.SimpleTableParser]]) -> Tuple[List[Any], str, List[Any]]: ...
    def table(self, isolate_function: Callable[[], Tuple[Union[List[Any], StringList], List[nodes.system_message], bool]], parser_class: Union[Type[tableparser.GridTableParser], Type[tableparser.SimpleTableParser]]) -> Tuple[List[N_co], bool]: ...
    def isolate_grid_table(self) -> Union[Tuple[List[Any], List[nodes.system_message], bool], Tuple[StringList, List[nodes.system_message], bool]]: ...
    def isolate_simple_table(self) -> Union[Tuple[List[Any], List[nodes.system_message], bool], Tuple[StringList, List[nodes.system_message], bool]]: ...
    def malformed_table(self, block: StringList, detail: str = ..., offset: int = ...) -> List[nodes.system_message]: ...
    def build_table(self, tabledata: Tuple[List[int], List[List[Tuple[int, int, int, StringList]]], List[List[Tuple[int, int, int, StringList]]]], tableline: int, stub_columns: int = ..., widths: Union[None, str, List[int]] = ...) -> nodes.table: ...
    def build_table_row(self, rowdata: List[Tuple[int, int, int, StringList]], tableline: int) -> nodes.row: ...
    explicit: states.Struct = ...
    def footnote(self, match: Match) -> Tuple[List[nodes.footnote], bool]: ...
    def citation(self, match: Match) -> Tuple[List[nodes.citation], bool]: ...
    def hyperlink_target(self, match: Match) -> Union[Tuple[List[nodes.target], bool], Tuple[List[str], bool]]: ...
    def make_target(self, block: List[str], block_text: str, lineno: int, target_name: str) -> Union[nodes.target, str]: ...
    def parse_target(self, block: List[str], block_text: str, lineno: int) -> Tuple[str, str]: ...
    def is_reference(self, reference: str) -> Optional[str]: ...
    def add_target(self, targetname: str, refuri: Optional[str], target: nodes.target, lineno: int) -> None: ...
    def substitution_def(self, match: Match) -> Union[Tuple[List[nodes.system_message], bool], Tuple[List[nodes.substitution_definition], bool]]: ...
    def disallowed_inside_substitution_definitions(self, node: nodes.Node) -> int: ...
    def directive(self, match: Match, **option_presets: Any) -> Union[Tuple[List[nodes.system_message], bool], Tuple[List[nodes.literal_block], bool], Tuple[List[nodes.system_message], bool]]: ...
    def run_directive(self, directive: Type[Directive], match: Match, type_name: str, option_presets: Dict[str, Any]) -> Union[Tuple[List[nodes.system_message], bool], Tuple[List[nodes.literal_block], bool]]: ...
    def parse_directive_block(self, indented: StringList, line_offset: int, directive: Directive, option_presets: Dict[str, Any]) -> Tuple[List[str], Dict[str, Any], StringList, int]: ...
    def parse_directive_options(self, option_presets: Dict[str, Any], option_spec: Dict[str, Callable[[str], str]], arg_block: Union[StringList, List[Any]]) -> Tuple[Dict[str, Any], StringList]: ...
    def parse_directive_arguments(self, directive: Directive, arg_block: Union[StringList, List[Any]]) -> List[str]: ...
    def parse_extension_options(self, option_spec: Dict[str, Callable[[str], str]], datalines: Union[StringList, List[Any]]) -> Tuple[int, Union[str, Dict[str, Any]]]: ...
    def unknown_directive(self, type_name: str) -> Tuple[List[nodes.system_message], bool]: ...
    def comment(self, match: Match) -> Tuple[List[nodes.comment], bool]: ...
    def explicit_markup(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def explicit_construct(self, match: Match) -> Union[Tuple[List[nodes.footnote], bool], Tuple[List[nodes.citation], bool], Tuple[List[nodes.target], bool], Tuple[List[str], bool], Tuple[List[nodes.system_message], bool], Tuple[List[nodes.substitution_definition], bool], Tuple[List[nodes.literal_block], bool], Tuple[List[Union[nodes.comment, nodes.system_message]], bool]]: ...
    def explicit_list(self, blank_finish: bool) -> None: ...
    def anonymous(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def anonymous_target(self, match: Match) -> Tuple[List[Union[nodes.target, str]], bool]: ...
    def line(self, match: Match, context: Any, next_state: str) -> Tuple[List[str], str, List[Any]]: ...
    def text(self, match: Match, context: Any, next_state: str) -> Optional[Tuple[List[str], str, List[Any]]]: ...

class RFC2822Body(Body):
    patterns: Dict[str, Union[str, Pattern]] = ...
    initial_transitions: Sequence[Tuple[str, str]] = ...
    def rfc2822(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def rfc2822_field(self, match: Match) -> Tuple[nodes.field, bool]: ...

class SpecializedBody(Body):
    def invalid_input(self, match: Optional[Match] = ..., context: Optional[Any] = ..., next_state: Optional[str] = ...) -> None: ...
    # Description quoted below is taken from the docstring of SpecializedBody::
    #
    #     All transition methods are disabled (redefined as `invalid_input`).
    #     Override individual methods in subclasses to re-enable.
    #
    # Considering this purpose, we do not type following methods.
    #
    # indent
    # bullet
    # enumerator
    # field_marker
    # option_marker
    # doctest
    # line_block
    # grid_table_top
    # simple_table_top
    # explicit_markup
    # anonymous
    # line
    # text

class BulletList(SpecializedBody):
    blank_finish: bool = ...
    def bullet(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...

class DefinitionList(SpecializedBody):
    def text(self, match: Match, context: Any, next_state: str) -> Tuple[List[str], str, List[Any]]: ...

class EnumeratedList(SpecializedBody):
    auto: int = ...
    blank_finish: bool = ...
    lastordinal: int = ...
    def enumerator(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...

class FieldList(SpecializedBody):
    blank_finish: bool = ...
    def field_marker(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...

class OptionList(SpecializedBody):
    blank_finish: bool = ...
    def option_marker(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...

class RFC2822List(SpecializedBody, RFC2822Body):
    patterns: Dict[str, Union[str, Pattern]] = ...
    initial_transitions: List[Tuple[str, str]] = ...
    blank_finish: bool = ...
    def rfc2822(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    # blank

class ExtensionOptions(FieldList):
    def parse_field_body(self, indented: StringList, offset: int, node: nodes.Node) -> None: ...

class LineBlock(SpecializedBody):
    # blank
    blank_finish: bool = ...
    def line_block(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...

class Explicit(SpecializedBody):
    blank_finish: bool = ...
    def explicit_markup(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def anonymous(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    # blank

class SubstitutionDef(Body):
    patterns: Dict[str, Union[str, Pattern]] = ...
    initial_transitions: List[str] = ...
    blank_finish: bool = ...
    def embedded_directive(self, match: Match, context: Any, next_state: str) -> None: ...
    def text(self, match: Match, context: Any, next_state: str) -> None: ...

class Text(RSTState):
    patterns: Dict[str, Union[str, Pattern]] = ...
    initial_transitions: List[Tuple[str, str]] = ...
    def blank(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def eof(self, context: Any) -> List[Any]: ...
    def indent(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def underline(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def text(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def literal_block(self) -> Union[List[N_co], List[Union[nodes.literal_block, nodes.system_message]]]: ...
    def quoted_literal_block(self) -> List[N_co]: ...
    def definition_list_item(self, termline: MutableSequence[str]) -> Tuple[nodes.definition_list_item, bool]: ...
    classifier_delimiter: Pattern = ...
    def term(self, lines: MutableSequence[str], lineno: int) -> Tuple[List[Union[nodes.term, nodes.classifier]], List[nodes.system_message]]: ...

class SpecializedText(Text):
    def eof(self, context: Any) -> List[Any]: ...
    def invalid_input(self, match: Optional[Match] = ..., context: Optional[Any] = ..., next_state: Optional[str] = ...): ...
    # Description quoted below is taken from the docstring of SpecializedBody::
    #
    #    All transition methods are disabled. Override individual methods in
    #    subclasses to re-enable.
    #
    # Considering this purpose, we do not type following methods.
    #
    # blank
    # indent
    # underline
    # text

class Definition(SpecializedText):
    def eof(self, context: Any) -> List[Any]: ...
    blank_finish: bool = ...
    def indent(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...

class Line(SpecializedText):
    eofcheck: int = ...
    def eof(self, context: Any) -> List[Any]: ...
    def blank(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def text(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    # indent
    def underline(self, match: Match, context: Any, next_state: str) -> Tuple[List[Any], str, List[Any]]: ...
    def short_overline(self, context: Any, blocktext: str, lineno: int, lines: int = ...) -> None: ...
    def state_correction(self, context: Any, lines: int = ...) -> None: ...

class QuotedLiteralBlock(RSTState):
    patterns: Dict[str, Union[str, Pattern]] = ...
    initial_transitions: Tuple[str, str] = ...
    messages: List[nodes.system_message] = ...
    initial_lineno: Optional[int] = ...
    def __init__(self, state_machine: StateMachine, debug: bool = ...) -> None: ...
    def blank(self, match: Match, context: Any, next_state: str) -> Tuple[Any, str, List[Any]]: ...
    def eof(self, context: Any) -> List[Any]: ...
    def indent(self, match: Match, context: Any, next_state: str) -> None: ...
    def initial_quoted(self, match: Match, context: Any, next_state: str) -> Tuple[List[str], str, List[Any]]: ...
    def quoted(self, match: Match, context: Any, next_state: str) -> Tuple[Any, str, List[Any]]: ...
    def text(self, match: Match, context: Any, next_state: str) -> None: ...

state_classes: Sequence[Type[RSTState]]



from setuptools import setup
import os


def find_stubs(package):
    stubs = []
    for root, dirs, files in os.walk(package):
        for file in files:
            path = os.path.join(root, file).replace(package + os.sep, '', 1)
            stubs.append(path)
    return {package: stubs}


setup(
    name='docutils-stubs',
    version='0.0.15',
    description='PEP 561 type stubs for docutils',
    long_description=open('README.rst').read(),
    url='https://github.com/tk0miya/docutils-stubs',
    author='Takeshi KOMIYA, cocoatomo',
    author_email='i.tkomiya@gmail.com, cocoatomo77@gmail.com',
    packages=['docutils-stubs'],
    install_requires=['docutils==0.14'],
    python_requires=">=3.5",
    package_data=find_stubs('docutils-stubs'),
    zip_safe=False,
)



# Stubs for docutils.readers (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import Component
from docutils import nodes
from docutils.frontend import Values
from docutils.io import Input
from docutils.parsers import Parser
from docutils.transforms import Transform
from typing import Any, List, Optional, Type

__docformat__: str

class Reader(Component):
    component_type: str = ...
    config_section: str = ...
    def get_transforms(self) -> List[Type[Transform]]: ...
    parser: Parser = ...
    source: Input = ...
    input: Any = ...
    def __init__(self, parser: Optional[Parser] = ..., parser_name: Optional[str] = ...) -> None: ...
    def set_parser(self, parser_name: str) -> None: ...
    settings: Values = ...
    def read(self, source: Input, parser: Parser, settings: Values) -> nodes.document: ...
    document: nodes.document = ...
    def parse(self) -> None: ...
    def new_document(self) -> nodes.document: ...

class ReReader(Reader):
    def get_transforms(self) -> List[Type[Transform]]: ...

def get_reader_class(reader_name: str) -> Reader: ...



# Stubs for docutils.utils.math.latex2mathml (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from typing import Any, Dict, List, Optional, Text, Tuple, TypeVar, Union

N_co = TypeVar('N_co', bound=nodes.Node, covariant=True)

over: Dict[str, Text]
Greek: Dict[str, Text]
letters: Dict[str, Text]
special: Dict[str, Text]
sumintprod: str
functions: List[str]
mathbb: Dict[str, Text]
mathscr: Dict[str, Text]
negatables: Dict[str, Text]

class math:
    nchildren: Optional[int] = ...
    children: Union[List[nodes.Node], nodes.Node] = ...
    inline: Optional[bool] = ...
    def __init__(self, children: Optional[Union[List[N_co], nodes.Node]] = ..., inline: Optional[bool] = ...) -> None: ...
    def full(self) -> bool: ...
    def append(self, child: nodes.Node) -> nodes.Node: ...
    def delete_child(self) -> nodes.Node: ...
    def close(self) -> nodes.Node: ...
    def xml(self) -> List[str]: ...
    def xml_start(self) -> List[str]: ...
    def xml_end(self) -> List[str]: ...
    def xml_body(self) -> List[str]: ...

class mrow(math):
    def xml_start(self) -> List[str]: ...

class mtable(math):
    def xml_start(self) -> List[str]: ...

class mtr(mrow): ...
class mtd(mrow): ...

class mx(math):
    nchildren: int = ...
    data: str = ...
    def __init__(self, data: str) -> None: ...
    def xml_body(self) -> List[str]: ...

class mo(mx):
    translation: Dict[str, str] = ...
    def xml_body(self) -> List[str]: ...

class mi(mx): ...
class mn(mx): ...

class msub(math):
    nchildren: int = ...

class msup(math):
    nchildren: int = ...

class msqrt(math):
    nchildren: int = ...

class mroot(math):
    nchildren: int = ...

class mfrac(math):
    nchildren: int = ...

class msubsup(math):
    nchildren: int = ...
    reversed: bool = ...
    def __init__(self, children: Optional[Union[List[N_co], nodes.Node]] = ..., reversed: bool = ...) -> None: ...
    def xml(self) -> List[str]: ...

class mfenced(math):
    translation: Dict[str, Text] = ...
    openpar: str = ...
    def __init__(self, par: str) -> None: ...
    def xml_start(self) -> List[str]: ...

class mspace(math):
    nchildren: int = ...

class mstyle(math):
    nchildren: Optional[int] = ...
    attrs: Any = ...
    def __init__(self, children: Optional[Union[List[N_co], nodes.Node]] = ..., nchildren: Optional[int] = ..., **kwargs: Any) -> None: ...
    def xml_start(self) -> List[str]: ...

class mover(math):
    nchildren: int = ...
    reversed: bool = ...
    def __init__(self, children: Optional[Union[List[N_co], nodes.Node]] = ..., reversed: bool = ...) -> None: ...
    def xml(self) -> List[str]: ...

class munder(math):
    nchildren: int = ...

class munderover(math):
    nchildren: int = ...
    def __init__(self, children: Optional[Union[List[N_co], nodes.Node]] = ...) -> None: ...

class mtext(math):
    nchildren: int = ...
    text: str = ...
    def __init__(self, text: str) -> None: ...
    def xml_body(self) -> List[str]: ...

def parse_latex_math(string: str, inline: bool = ...) -> math: ...
def handle_keyword(name: str, node: math, string: str) -> Tuple[math, int]: ...
def tex2mathml(tex_math: str, inline: bool = ...) -> str: ...



# Stubs for docutils.parsers.rst.directives.references (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Node
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class TargetNotes(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...



# Stubs for docutils.utils.math.tex2mathml_extern (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.utils import Reporter
from typing import Optional

document_template: str

def latexml(math_code: str, reporter: Optional[Reporter] = ...): ...
def ttm(math_code: str, reporter: Optional[Reporter] = ...): ...
def blahtexml(math_code: str, inline: bool = ..., reporter: Optional[Reporter] = ...): ...



# Stubs for docutils.writers.null (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import writers
from typing import Sequence, Tuple

class Writer(writers.UnfilteredWriter):
    supported: Tuple[str, ...] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    def translate(self) -> None: ...



# Stubs for docutils.nodes (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import SettingsSpec
from docutils import nodes
from docutils.transforms import Transformer, Transform
from docutils.utils import Reporter

from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, overload, Tuple, Type, TypeVar

__docformat__: str

N_co = TypeVar('N_co', bound=nodes.Node, covariant=True)
N = TypeVar('N', bound=nodes.Node)
E = TypeVar('E', bound=nodes.Element)

class Node:
    parent: nodes.Element = ...
    document: nodes.document = ...
    source: str = ...
    line: int = ...
    def __bool__(self) -> bool: ...
    def asdom(self, dom: Optional[Any] = ...) -> Any: ...
    def pformat(self, indent: str = ..., level: int = ...) -> str: ...
    def copy(self) -> nodes.Node: ...
    def deepcopy(self) -> nodes.Node: ...
    def setup_child(self, child: nodes.Node) -> None: ...
    def walk(self, visitor: nodes.NodeVisitor) -> bool: ...
    def walkabout(self, visitor: nodes.NodeVisitor) -> bool: ...

    @overload
    def traverse(self, condition: Type[N] = ..., include_self: bool = ..., descend: bool = ..., siblings: bool = ..., ascend: bool = ...) -> List[N]: ...
    @overload  # NOQA: F811
    def traverse(self, condition: Callable[[nodes.Node], bool] = ..., include_self: bool = ..., descend: bool = ..., siblings: bool = ..., ascend: bool = ...) -> List[N]: ...

    def next_node(self, condition: Optional[Any] = ..., include_self: bool = ..., descend: bool = ..., siblings: bool = ..., ascend: bool = ...) -> nodes.Node: ...

def ensure_str(s: str) -> str: ...

class Text(Node, str):
    tagname: str = ...
    children: Tuple[nodes.Node, ...] = ...
    rawsource: str = ...
    def __new__(cls, data: str, rawsource: Optional[str] = ...): ...
    def __init__(self, data: str, rawsource: str = ...) -> None: ...
    def shortrepr(self, maxlen: int = ...) -> str: ...
    def astext(self) -> str: ...
    def copy(self) -> nodes.Text: ...
    def deepcopy(self) -> nodes.Text: ...
    def pformat(self, indent: str = ..., level: int = ...) -> str: ...
    def rstrip(self, chars: Optional[str] = ...) -> str: ...
    def lstrip(self, chars: Optional[str] = ...) -> str: ...

class Element(Node):
    basic_attributes: Tuple[str, ...] = ...
    local_attributes: Tuple[str, ...] = ...
    list_attributes: Tuple[str, ...] = ...
    known_attributes: Tuple[str, ...] = ...
    tagname: str = ...
    child_text_separator: str = ...
    rawsource: str = ...
    children: List[nodes.Node] = ...
    attributes: Dict[str, Any] = ...
    def __init__(self, rawsource: str = ..., *children: nodes.Node, **attributes: Any) -> None: ...
    def shortrepr(self) -> str: ...
    def __unicode__(self) -> str: ...
    def starttag(self, quoteattr: Optional[Callable[[str], str]] = ...) -> str: ...
    def endtag(self) -> str: ...
    def emptytag(self) -> str: ...
    def __len__(self) -> int: ...

    @overload
    def __getitem__(self, key: str) -> Any: ...
    @overload  # NOQA: F811
    def __getitem__(self, key: int) -> nodes.Node: ...
    @overload  # NOQA: F811
    def __getitem__(self, key: slice) -> List[N_co]: ...

    def __setitem__(self, key: Any, item: Any) -> Any: ...
    def __delitem__(self, key: Any) -> Any: ...
    def __add__(self, other: List[N_co]) -> List[N_co]: ...
    def __radd__(self, other: List[N_co]) -> List[N_co]: ...
    def __iadd__(self: E, other: Any) -> E: ...  # type: ignore
    def astext(self) -> str: ...
    def non_default_attributes(self) -> Dict[str, Any]: ...
    def attlist(self) -> List[Tuple[str, Any]]: ...
    def get(self, key: str, failobj: Optional[Any] = ...) -> Any: ...
    def hasattr(self, attr: str) -> bool: ...
    def delattr(self, attr: str) -> None: ...
    def setdefault(self, key: str, failobj: Optional[Any] = ...) -> Any: ...
    def has_key(self, attr: str) -> bool: ...
    def __contains__(self, attr: str) -> bool: ...
    def get_language_code(self, fallback: str = ...) -> str: ...
    def append(self, item: nodes.Node) -> None: ...
    def extend(self, item: Iterable[nodes.Node]) -> None: ...
    def insert(self, index: int, item: Any) -> None: ...
    def pop(self, i: int = ...) -> nodes.Node: ...
    def remove(self, item: nodes.Node) -> None: ...
    def index(self, item: nodes.Node) -> int: ...
    def is_not_default(self, key: str) -> int: ...
    def update_basic_atts(self, dict_: Any) -> None: ...
    def append_attr_list(self, attr: str, values: List) -> None: ...
    def coerce_append_attr_list(self, attr: str, value) -> None: ...
    def replace_attr(self, attr: str, value: Any, force: bool = ...) -> None: ...
    def copy_attr_convert(self, attr: str, value: Any, replace: bool = ...) -> None: ...
    def copy_attr_coerce(self, attr: str, value: Any, replace: bool) -> None: ...
    def copy_attr_concatenate(self, attr: str, value: Any, replace: bool) -> None: ...
    def copy_attr_consistent(self, attr: str, value: Any, replace: bool) -> None: ...
    def update_all_atts(self, dict_, update_fun: Callable[[str, Any, bool], None] = ..., replace: bool = ..., and_source: bool = ...) -> None: ...
    def update_all_atts_consistantly(self, dict_: Any, replace: bool = ..., and_source: bool = ...) -> None: ...
    def update_all_atts_concatenating(self, dict_: Any, replace: bool = ..., and_source: bool = ...) -> None: ...
    def update_all_atts_coercion(self, dict_: Any, replace: bool = ..., and_source: bool = ...) -> None: ...
    def update_all_atts_convert(self, dict_: Any, and_source: bool = ...) -> None: ...
    def clear(self) -> None: ...
    def replace(self, old: nodes.Node, new: Any) -> None: ...
    def replace_self(self, new: Any) -> None: ...
    def first_child_matching_class(self, childclass: Any, start: int = ..., end: int = ...) -> int: ...
    def first_child_not_matching_class(self, childclass: Any, start: int = ..., end: int = ...) -> int: ...
    def pformat(self, indent: str = ..., level: int = ...) -> str: ...
    def copy(self) -> nodes.Element: ...
    def deepcopy(self) -> nodes.Element: ...
    def set_class(self, name: str) -> None: ...
    referenced: int = ...
    def note_referenced_by(self, name: Optional[str] = ..., id: Optional[str] = ...) -> None: ...
    @classmethod
    def is_not_list_attribute(cls, attr: str) -> bool: ...
    @classmethod
    def is_not_known_attribute(cls, attr: str) -> bool: ...

    # dummy atribute to indicate to mypy that Element is Iterable
    def __iter__(self) -> Iterator[nodes.Node]: ...

class TextElement(Element):
    child_text_separator: str = ...
    def __init__(self, rawsource: str = ..., text: str = ..., *children: nodes.Node, **attributes: Any) -> None: ...

class FixedTextElement(TextElement):
    def __init__(self, rawsource: str = ..., text: str = ..., *children: nodes.Node, **attributes: Any) -> None: ...

class Resolvable:
    resolved: int = ...

class BackLinkable:
    def add_backref(self, refid: str) -> None: ...

class Root: ...
class Titular: ...
class PreBibliographic: ...
class Bibliographic: ...
class Decorative(PreBibliographic): ...
class Structural: ...
class Body: ...
class General(Body): ...
class Sequential(Body): ...
class Admonition(Body): ...
class Special(Body): ...
class Invisible(PreBibliographic): ...
class Part: ...
class Inline: ...
class Referential(Resolvable): ...

class Targetable(Resolvable):
    referenced: int = ...
    indirect_reference_name: str = ...

class Labeled: ...

class document(Root, Structural, Element):
    current_source: str = ...
    current_line: str = ...
    settings: SettingsSpec = ...
    reporter: Reporter = ...
    indirect_targets: List[nodes.target] = ...
    substitution_defs: Dict[str, nodes.substitution_definition] = ...
    substitution_names: Dict[str, str] = ...
    refnames: Dict[str, List[nodes.Element]] = ...
    refids: Dict[str, List[nodes.Element]] = ...
    nameids: Dict[str, str] = ...
    nametypes: Dict[str, bool] = ...
    ids: Dict[str, nodes.Element] = ...
    footnote_refs: Dict[str, List[nodes.footnote_reference]] = ...
    citation_refs: Dict[str, List[nodes.citation_reference]] = ...
    autofootnotes: List[nodes.footnote] = ...
    autofootnote_refs: List[nodes.footnote_reference] = ...
    symbol_footnotes: List[nodes.footnote] = ...
    symbol_footnote_refs: List[nodes.footnote_reference] = ...
    footnotes: List[nodes.footnote] = ...
    citations: List[nodes.citation] = ...
    autofootnote_start: int = ...
    symbol_footnote_start: int = ...
    id_start: int = ...
    parse_messages: List[nodes.system_message] = ...
    transform_messages: List[nodes.system_message] = ...
    transformer: Transformer = ...
    decoration: nodes.decoration = ...
    document: nodes.document = ...
    def __init__(self, settings: SettingsSpec, reporter: Reporter, *args: nodes.Node, **kwargs: Any) -> None: ...
    def asdom(self, dom: Optional[Any] = ...) -> Any: ...
    def set_id(self, node: nodes.Element, msgnode: Optional[nodes.Element] = ...) -> str: ...
    def set_name_id_map(self, node: nodes.Element, id: str, msgnode: Optional[nodes.Element] = ..., explicit: Optional[bool] = ...) -> None: ...
    def set_duplicate_name_id(self, node: nodes.Element, id: str, name: str, msgnode: nodes.Element, explicit: bool) -> None: ...
    def has_name(self, name: str) -> bool: ...
    def note_implicit_target(self, target: nodes.Element, msgnode: Optional[nodes.Element] = ...) -> None: ...
    def note_explicit_target(self, target: nodes.Element, msgnode: Optional[nodes.Element] = ...) -> None: ...
    def note_refname(self, node: nodes.Element) -> None: ...
    def note_refid(self, node: nodes.Element) -> None: ...
    def note_indirect_target(self, target: nodes.target) -> None: ...
    def note_anonymous_target(self, target: nodes.target) -> None: ...
    def note_autofootnote(self, footnote: nodes.footnote) -> None: ...
    def note_autofootnote_ref(self, ref: nodes.footnote_reference) -> None: ...
    def note_symbol_footnote(self, footnote: nodes.footnote) -> None: ...
    def note_symbol_footnote_ref(self, ref: nodes.footnote_reference) -> None: ...
    def note_footnote(self, footnote: nodes.footnote) -> None: ...
    def note_footnote_ref(self, ref: nodes.footnote_reference) -> None: ...
    def note_citation(self, citation: nodes.citation) -> None: ...
    def note_citation_ref(self, ref: nodes.citation_reference) -> None: ...
    def note_substitution_def(self, subdef: nodes.substitution_definition, def_name: str, msgnode: Optional[nodes.Element] = ...) -> None: ...
    def note_substitution_ref(self, subref: nodes.substitution_reference, refname: str) -> None: ...
    def note_pending(self, pending: nodes.pending, priority: Optional[int] = ...) -> None: ...
    def note_parse_message(self, message: nodes.system_message) -> None: ...
    def note_transform_message(self, message: nodes.system_message) -> None: ...
    def note_source(self, source: str, offset: int) -> None: ...
    def copy(self) -> nodes.document: ...
    def get_decoration(self) -> nodes.decoration: ...

class title(Titular, PreBibliographic, TextElement): ...
class subtitle(Titular, PreBibliographic, TextElement): ...
class rubric(Titular, TextElement): ...
class docinfo(Bibliographic, Element): ...
class author(Bibliographic, TextElement): ...
class authors(Bibliographic, Element): ...
class organization(Bibliographic, TextElement): ...
class address(Bibliographic, FixedTextElement): ...
class contact(Bibliographic, TextElement): ...
class version(Bibliographic, TextElement): ...
class revision(Bibliographic, TextElement): ...
class status(Bibliographic, TextElement): ...
class date(Bibliographic, TextElement): ...
class copyright(Bibliographic, TextElement): ...

class decoration(Decorative, Element):
    def get_header(self) -> nodes.header: ...
    def get_footer(self) -> nodes.footer: ...

class header(Decorative, Element): ...
class footer(Decorative, Element): ...
class section(Structural, Element): ...
class topic(Structural, Element): ...
class sidebar(Structural, Element): ...
class transition(Structural, Element): ...
class paragraph(General, TextElement): ...
class compound(General, Element): ...
class container(General, Element): ...
class bullet_list(Sequential, Element): ...
class enumerated_list(Sequential, Element): ...
class list_item(Part, Element): ...
class definition_list(Sequential, Element): ...
class definition_list_item(Part, Element): ...
class term(Part, TextElement): ...
class classifier(Part, TextElement): ...
class definition(Part, Element): ...
class field_list(Sequential, Element): ...
class field(Part, Element): ...
class field_name(Part, TextElement): ...
class field_body(Part, Element): ...

class option(Part, Element):
    child_text_separator: str = ...

class option_argument(Part, TextElement):
    def astext(self) -> str: ...

class option_group(Part, Element):
    child_text_separator: str = ...

class option_list(Sequential, Element): ...

class option_list_item(Part, Element):
    child_text_separator: str = ...

class option_string(Part, TextElement): ...
class description(Part, Element): ...
class literal_block(General, FixedTextElement): ...
class doctest_block(General, FixedTextElement): ...
class math_block(General, FixedTextElement): ...
class line_block(General, Element): ...

class line(Part, TextElement):
    indent: Any = ...

class block_quote(General, Element): ...
class attribution(Part, TextElement): ...
class attention(Admonition, Element): ...
class caution(Admonition, Element): ...
class danger(Admonition, Element): ...
class error(Admonition, Element): ...
class important(Admonition, Element): ...
class note(Admonition, Element): ...
class tip(Admonition, Element): ...
class hint(Admonition, Element): ...
class warning(Admonition, Element): ...
class admonition(Admonition, Element): ...
class comment(Special, Invisible, FixedTextElement): ...
class substitution_definition(Special, Invisible, TextElement): ...
class target(Special, Invisible, Inline, TextElement, Targetable): ...
class footnote(General, BackLinkable, Element, Labeled, Targetable): ...
class citation(General, BackLinkable, Element, Labeled, Targetable): ...
class label(Part, TextElement): ...
class figure(General, Element): ...
class caption(Part, TextElement): ...
class legend(Part, Element): ...
class table(General, Element): ...
class tgroup(Part, Element): ...
class colspec(Part, Element): ...
class thead(Part, Element): ...
class tbody(Part, Element): ...
class row(Part, Element): ...
class entry(Part, Element): ...

class system_message(Special, BackLinkable, PreBibliographic, Element):
    def __init__(self, message: Optional[str] = ..., *children: nodes.Node, **attributes: Any) -> None: ...
    def astext(self) -> str: ...

class pending(Special, Invisible, Element):
    transform: Transform = ...
    details: Dict = ...
    def __init__(self, transform: Transform, details: Optional[Dict] = ..., rawsource: str = ..., *children: nodes.Node, **attributes: Any) -> None: ...
    def pformat(self, indent: str = ..., level: int = ...) -> str: ...
    def copy(self) -> nodes.system_message: ...

class raw(Special, Inline, PreBibliographic, FixedTextElement): ...
class emphasis(Inline, TextElement): ...
class strong(Inline, TextElement): ...
class literal(Inline, TextElement): ...
class reference(General, Inline, Referential, TextElement): ...
class footnote_reference(Inline, Referential, TextElement): ...
class citation_reference(Inline, Referential, TextElement): ...
class substitution_reference(Inline, TextElement): ...
class title_reference(Inline, TextElement): ...
class abbreviation(Inline, TextElement): ...
class acronym(Inline, TextElement): ...
class superscript(Inline, TextElement): ...
class subscript(Inline, TextElement): ...
class math(Inline, TextElement): ...

class image(General, Inline, Element):
    def astext(self) -> str: ...

class inline(Inline, TextElement): ...
class problematic(Inline, TextElement): ...
class generated(Inline, TextElement): ...

node_class_names: List[str] = ...

class NodeVisitor:
    optional: Tuple[str, ...] = ...
    document: nodes.document = ...
    def __init__(self, document: nodes.document) -> None: ...
    def dispatch_visit(self, node: nodes.Node) -> Any: ...
    def dispatch_departure(self, node: nodes.Node) -> Any: ...
    def unknown_visit(self, node: nodes.Node) -> Any: ...
    def unknown_departure(self, node: nodes.Node) -> Any: ...

class SparseNodeVisitor(NodeVisitor): ...

class GenericNodeVisitor(NodeVisitor):
    def default_visit(self, node: nodes.Node) -> Any: ...
    def default_departure(self, node: nodes.Node) -> Any: ...

class TreeCopyVisitor(GenericNodeVisitor):
    parent_stack: List[nodes.Node] = ...
    parent: List[nodes.Node] = ...
    def __init__(self, document: nodes.document) -> None: ...
    def get_tree_copy(self) -> nodes.Node: ...
    def default_visit(self, node: nodes.Node) -> None: ...
    def default_departure(self, node: nodes.Node) -> None: ...

class TreePruningException(Exception): ...
class SkipChildren(TreePruningException): ...
class SkipSiblings(TreePruningException): ...
class SkipNode(TreePruningException): ...
class SkipDeparture(TreePruningException): ...
class NodeFound(TreePruningException): ...
class StopTraversal(TreePruningException): ...

def make_id(string: str) -> str: ...
def dupname(node: nodes.Element, name: str) -> None: ...
def fully_normalize_name(name: str) -> str: ...
def whitespace_normalize_name(name: str) -> str: ...
def serial_escape(value: str) -> str: ...
def pseudo_quoteattr(value: str) -> str: ...



# Stubs for docutils.transforms.peps (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils import nodes
from docutils.transforms import Transform
from typing import Optional, Pattern, Sequence, Tuple

__docformat__: str

class Headers(Transform):
    default_priority: int = ...
    pep_url: str = ...
    pep_cvs_url: str = ...
    rcs_keyword_substitutions: Sequence[Tuple[Pattern, str]] = ...
    def apply(self) -> None: ...  # type: ignore

class Contents(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class TargetNotes(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore
    def cleanup_callback(self, pending: nodes.pending) -> None: ...

class PEPZero(Transform):
    default_priority: int = ...
    def apply(self) -> None: ...  # type: ignore

class PEPZeroSpecial(nodes.SparseNodeVisitor):
    pep_url: str = ...
    def unknown_visit(self, node: nodes.Node) -> None: ...
    def visit_reference(self, node: nodes.Node) -> None: ...
    def visit_field_list(self, node: nodes.Node) -> None: ...
    pep_table: bool = ...
    entry: int = ...
    def visit_tgroup(self, node: nodes.Node) -> None: ...
    def visit_colspec(self, node: nodes.Node) -> None: ...
    def visit_row(self, node: nodes.Node) -> None: ...
    def visit_entry(self, node: nodes.Node) -> None: ...

non_masked_addresses: Sequence[str]

def mask_email(ref: nodes.Node, pepno: Optional[int] = ...) -> nodes.Node: ...



# Stubs for docutils.parsers.rst.directives.images (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Node
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, Tuple, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class PIL: ...

class Image(Directive):
    align_h_values: Tuple[str, ...] = ...
    align_v_values: Tuple[str, ...] = ...
    align_values: Tuple[str, ...] = ...
    required_arguments: int = ...
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class Figure(Image):
    def align(argument): ...
    def figwidth_value(argument): ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...



# Stubs for docutils.readers.pep (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.parsers import Parser
from docutils.parsers.rst.states import Inliner
from docutils.readers import standalone
from docutils.transforms import Transform
from typing import Any, Dict, List, Optional, Sequence, Tuple, Type

__docformat__: str

class Reader(standalone.Reader):
    supported: Tuple[str, ...] = ...
    settings_spec: Tuple[str, str, Tuple[str, List[str], Dict[str, Any]]] = ...
    config_section: str = ...
    config_section_dependencies: Sequence[str] = ...
    def get_transforms(self) -> List[Type[Transform]]: ...
    settings_default_overrides: Dict[str, Any] = ...
    inliner_class: Type[Inliner] = ...
    def __init__(self, parser: Optional[Parser] = ..., parser_name: Optional[str] = ...) -> None: ...



# Stubs for docutils.languages (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from types import ModuleType
from typing import Optional
from docutils.utils import Reporter

__docformat__: str

def get_language(language_code: str, reporter: Optional[Reporter] = ...) -> ModuleType: ...



# Stubs for docutils.parsers.rst.directives.body (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from docutils.nodes import Element, Node, topic, sidebar
from docutils.parsers.rst import Directive
from typing import Any, Callable, Dict, List, TypeVar

N_co = TypeVar('N_co', bound=Node, covariant=True)

__docformat__: str

class BasePseudoSection(Directive):
    required_arguments: int = ...
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    node_class: Element = ...
    def run(self) -> List[N_co]: ...

class Topic(BasePseudoSection):
    node_class: topic = ...

class Sidebar(BasePseudoSection):
    node_class: sidebar = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class LineBlock(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class ParsedLiteral(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class CodeBlock(Directive):
    optional_arguments: int = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class MathBlock(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class Rubric(Directive):
    required_arguments: int = ...
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    def run(self) -> List[N_co]: ...

class BlockQuote(Directive):
    has_content: bool = ...
    classes: List[str] = ...
    def run(self) -> List[N_co]: ...

class Epigraph(BlockQuote):
    classes: List[str] = ...

class Highlights(BlockQuote):
    classes: List[str] = ...

class PullQuote(BlockQuote):
    classes: List[str] = ...

class Compound(Directive):
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...

class Container(Directive):
    optional_arguments: int = ...
    final_argument_whitespace: bool = ...
    option_spec: Dict[str, Callable[[str], Any]] = ...
    has_content: bool = ...
    def run(self) -> List[N_co]: ...
